@@ -16,7 +16,7 @@
 #' 
 #' @param expr,value An \R \link[base]{expression}.
 #'
-#' @param \dots Reserved for internal use only.
+#' @param \dots Additional arguments passed to [Future()].
 #'
 #' @return
 #' `f <- future(expr)` creates a [Future] `f` that evaluates expression `expr`, the value of the future is retrieved using `v <- value(f)`.
@@ -186,28 +186,61 @@
 #' @aliases futureCall
 #' @export
 #' @name future
-future <- function(expr, envir = parent.frame(), substitute = TRUE, globals = TRUE, packages = NULL, seed = FALSE, lazy = FALSE, ...) {
+future <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = FALSE, globals = TRUE, packages = NULL, stdout = TRUE, conditions = "condition", earlySignal = FALSE, label = NULL, gc = FALSE, ...) {
   if (substitute) expr <- substitute(expr)
 
-  ## Argument 'evaluator' is defunct
-  if (!is.null(list(...)$evaluator)) {
-    .Defunct(msg = "Argument 'evaluator' of future() was an internal argument and is now defunct. Use plan() to set the \"evaluator\".")
+  gp <- getGlobalsAndPackages(expr, envir = envir, tweak = tweakExpression, globals = globals)
+  expr <- gp$expr
+  globals <- gp$globals
+  ## Record packages?
+  if (length(packages) > 0 || length(gp$packages) > 0) {
+    packages <- unique(c(gp$packages, packages))
   }
-  makeFuture <- plan("next")
-  ## Sanity check
-  stopifnot(is.function(makeFuture))
+  gp <- NULL
+  attr(globals, "already-done") <- TRUE
+  
+  future <- Future(expr, substitute = FALSE,
+                   envir = envir,
+                   lazy = TRUE,
+                   seed = seed,
+                   globals = globals,
+                   packages = packages,
+                   stdout = stdout,
+                   conditions = conditions,
+                   earlySignal = earlySignal,
+                   label = label,
+                   gc = gc,
+                   ...)
 
-  future <- makeFuture(expr, substitute = FALSE,
-                       envir = envir,
-                       globals = globals, packages = packages,
-                       seed = seed,
-                       lazy = lazy,
-                       ...)
+  ## WORKAROUND: Was argument 'local' specified?
+  ## Comment: Only allowed for persistent 'cluster' futures
+  future$.defaultLocal <- !is.element("local", names(list(...)))
 
-  ## Assert that a future was returned
-  if (!inherits(future, "Future")) {
-    stop(FutureError("plan(\"next\") returned a function that does not return a Future object: ", paste(sQuote(class(future)), collapse = ", ")))
+  if (!lazy) {
+    future <- run(future)
+    future$lazy <- FALSE
+    ## Assert that a future was returned
+    stop_if_not(inherits(future, "Future"), !future$lazy)
   }
 
   future
 }
+
+## Arguments to 'future' strategies that must not be tweaked
+attr(future, "untweakable") <- c(
+  "asynchronous",  ## reserved
+  "conditions",
+  "envir",
+  "expr",
+  "globals",
+  "lazy",
+  "local",
+  "packages",
+  "seed",
+  "stdout",
+  "substitute",
+  "version"        ## for internal backend use
+)
+
+## Hidden arguments to 'future' strategy that my also be tweaked
+attr(future, "tweakable") <- c("earlySignal", "split")
