@@ -3,12 +3,20 @@ library("listenv")
 
 message("*** transparent() ...")
 
+message("- transparent() is defunct")
+res <- tryCatch(plan(transparent), error = identity)
+stopifnot(inherits(res, "error"))  ## defunctError in R (>= 4.0.0)
+
+
+message("- transparent() legacy behavior")
+options(future.deprecated.defunct = NULL)
+
 ## No global variables
 f <- try(transparent({
   42L
-}), silent=FALSE)
+}), silent = FALSE)
 print(f)
-stopifnot(inherits(f, "UniprocessFuture"), !f$lazy)
+stopifnot(inherits(f, "SequentialFuture"), !f$lazy)
 
 print(resolved(f))
 y <- value(f)
@@ -20,9 +28,9 @@ plan(transparent)
 ## No global variables
 f <- try(future({
   42L
-}), silent=FALSE)
+}), silent = FALSE)
 print(f)
-stopifnot(inherits(f, "UniprocessFuture"), !f$lazy)
+stopifnot(inherits(f, "SequentialFuture"), !f$lazy)
 
 print(resolved(f))
 y <- value(f)
